@@ -1,9 +1,10 @@
 module ActiveResource
   module VERSION #:nodoc:
     MAJOR = 3
-    MINOR = 0
+    MINOR = 1
     TINY  = 3
-        
-    STRING = [MAJOR, MINOR, TINY].join('.')
+    PRE   = nil
+
+    STRING = [MAJOR, MINOR, TINY, PRE].compact.join('.')
   end
 end
